@@ -3,9 +3,11 @@ from .diagnostics import potential_scale_reduction as rhat
 from .kernels import (
     adaptive_tempered_smc,
     elliptical_slice,
+    ghmc,
     hmc,
     irmh,
     mala,
+    meads,
     mgrad_gaussian,
     nuts,
     orbital_hmc,
@@ -18,7 +20,7 @@ from .kernels import (
 )
 from .optimizers import dual_averaging, lbfgs
 
-__version__ = "0.8.3"
+__version__ = "0.9.0"
 
 __all__ = [
     "dual_averaging",  # optimizers
@@ -31,6 +33,8 @@ __all__ = [
     "rmh",
     "irmh",
     "elliptical_slice",
+    "ghmc",
+    "meads",
     "sgld",  # stochastic gradient mcmc
     "sghmc",
     "window_adaptation",  # mcmc adaptation
